@@ -2,7 +2,7 @@
 /**
  * Index script.
  *
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -16,12 +16,4 @@
 require_once __DIR__ . '/lib/Application.php';
 Horde_Registry::appInit('ingo');
 
-switch ($registry->getView()) {
-case $registry::VIEW_SMARTMOBILE:
-    Horde::url('smartmobile.php')->redirect();
-    break;
-
-default:
-    Ingo_Basic_Filters::url()->redirect();
-    break;
-}
+Ingo::getInitialPage()->redirect();
