@@ -1,4 +1,16 @@
+/**
+ * Provides the javascript for the blacklist view.
+ *
+ * @author     Michael Slusarz <slusarz@horde.org>
+ * @copyright  2014 Horde LLC
+ * @license    ASL (http://www.horde.org/licenses/apache)
+ */
+
 var IngoBlacklist = {
+
+    // Vars used and defaulting to null/false:
+    //   filtersurl
+
     onDomLoad: function()
     {
         $('actionvalue').observe('change', function(e) {
@@ -8,7 +20,7 @@ var IngoBlacklist = {
         });
 
         $('blacklist_return').observe('click', function(e) {
-            document.location.href = IngoBlacklist.filtersurl;
+            document.location.href = this.filtersurl;
             e.stop();
         }.bind(this));
     }
