@@ -26,7 +26,21 @@ var IngoFilters = {
                 onUpdate: function() {
                     HordeCore.doAction(
                         'reSortFilters',
-                        { sort: Object.toJSON(Sortable.sequence('filterslist')) }
+                        {
+                            sort: Object.toJSON(Sortable.sequence('filterslist'))
+                        },
+                        {
+                            callback: function() {
+                                /* Need to re-label the IDs to reflect new
+                                 * sort order. */
+                                var i = 0,
+                                    rows = $('filterslist').select('DIV.filtersRow');
+                                rows.invoke('writeAttribute', 'id', null);
+                                rows.each(function(r) {
+                                    r.writeAttribute('id', 'filtersrow_' + (i++));
+                                });
+                            }
+                        }
                     );
                 },
                 tag: 'div'
