@@ -1,15 +1,18 @@
 /**
- * See the enclosed file COPYING for license information (GPL). If you
- * did not receive this file, see http://www.horde.org/licenses/gpl.
+ * Provides the javascript for the rule view.
+ *
+ * @author     Michael Slusarz <slusarz@horde.org>
+ * @copyright  2014 Horde LLC
+ * @license    ASL (http://www.horde.org/licenses/apache)
  */
 
 var IngoRule = {
 
     delete_condition: function(num)
     {
-        document.rule.actionID.value = 'rule_delete';
-        document.rule.conditionnumber.value = num;
-        document.rule.submit();
+        $('actionID').setValue('rule_delete');
+        $('conditionnumber').setValue(num);
+        $('rule').submit();
         return true;
     },
 
