@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2013 Horde LLC
+ * @copyright 2013-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -17,7 +17,7 @@
  * @author    Mike Cochrane <mike@graftonhall.co.nz>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2013 Horde LLC
+ * @copyright 2013-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -27,25 +27,16 @@ class Ingo_Basic_Blacklist extends Ingo_Basic_Base
      */
     protected function _init()
     {
-        global $injector, $notification, $page_output, $prefs, $session;
+        global $injector, $notification, $page_output;
 
-        /* Redirect if blacklist is not available. */
-        if (!in_array(Ingo_Storage::ACTION_BLACKLIST, $session->get('ingo', 'script_categories'))) {
-            $notification->push(_("Blacklist is not supported in the current filtering driver."), 'horde.error');
-            Ingo_Basic_Filters::url()->redirect();
-        }
+        $this->_assertCategory(Ingo_Storage::ACTION_BLACKLIST, _("Blacklist"));
 
         $ingo_script = $injector->getInstance('Ingo_Factory_Script')->create(Ingo::RULE_BLACKLIST);
         $ingo_storage = $injector->getInstance('Ingo_Factory_Storage')->create();
-        $blacklist_folder = $folder = null;
-
         $flagonly = ($ingo_script && in_array(Ingo_Storage::ACTION_FLAGONLY, $ingo_script->availableActions()));
 
-        /* Token checking. */
-        $actionID = $this->_checkToken(array('rule_update'));
-
-        /* Perform requested actions. */
-        switch ($actionID) {
+        /* Token checking & perform requested actions. */
+        switch ($this->_checkToken(array('rule_update'))) {
         case 'rule_update':
             switch ($this->vars->action) {
             case 'delete':
@@ -57,7 +48,11 @@ class Ingo_Basic_Blacklist extends Ingo_Basic_Base
                 break;
 
             case 'folder':
-                $folder = Ingo::validateFolder($this->vars, 'actionvalue');
+                $folder = $this->validateMbox('actionvalue');
+                break;
+
+            default:
+                $folder = null;
                 break;
             }
 
@@ -69,15 +64,10 @@ class Ingo_Basic_Blacklist extends Ingo_Basic_Base
                     $blacklist->setBlacklistFolder($folder);
                     $ingo_storage->store($blacklist);
                     $notification->push(_("Changes saved."), 'horde.success');
-                    if ($prefs->getValue('auto_update')) {
-                        Ingo::updateScript();
-                    }
+                    Ingo_Script_Util::update();
                 } catch (Ingo_Exception $e) {
                     $notification->push($e->getMessage(), $e->getCode());
                 }
-
-                /* Update the timestamp for the rules. */
-                $session->set('ingo', 'change', time());
             }
             break;
         }
@@ -93,10 +83,8 @@ class Ingo_Basic_Blacklist extends Ingo_Basic_Base
         }
 
         /* Create the folder listing. */
-        if (!isset($blacklist_folder)) {
-            $blacklist_folder = $blacklist->getBlacklistFolder();
-        }
-        $folder_list = Ingo::flistSelect($blacklist_folder, 'actionvalue');
+        $blacklist_folder = $blacklist->getBlacklistFolder();
+        $folder_list = Ingo_Flist::select($blacklist_folder, 'actionvalue');
 
         /* Get the blacklist rule. */
         $bl_rule = $ingo_storage->retrieve(Ingo_Storage::ACTION_FILTERS)->findRule(Ingo_Storage::ACTION_BLACKLIST);
