@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -17,7 +17,7 @@
  * @author    Mike Cochrane <mike@graftonhall.co.nz>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -45,18 +45,26 @@ class Ingo_Basic_Filters extends Ingo_Basic_Base
 
         /* Token checking. */
         $actionID = $this->_checkToken(array(
-            'rule_down',
-            'rule_up',
             'rule_copy',
             'rule_delete',
             'rule_disable',
-            'rule_enable',
+            'rule_enable'
         ));
 
+        /* Default to no mailbox filtering. */
+        $mbox_search = null;
+
         /* Perform requested actions. */
         switch ($actionID) {
-        case 'rule_down':
-        case 'rule_up':
+        case 'mbox_search':
+            if (isset($this->vars->searchfield)) {
+                $mbox_search = array(
+                    'exact' => $this->vars->get('searchexact', 1),
+                    'query' => $this->vars->searchfield
+                );
+            }
+            break;
+
         case 'rule_copy':
         case 'rule_delete':
         case 'rule_disable':
@@ -80,35 +88,28 @@ class Ingo_Basic_Filters extends Ingo_Basic_Base
                 break;
 
             case 'rule_copy':
-                if (!$perms->hasAppPermission('allow_rules')) {
-                    Horde::permissionDeniedError(
-                        'ingo',
-                        'allow_rules',
-                        _("You are not allowed to create or edit custom rules.")
-                    );
-                    break 2;
-                } elseif (($perms->hasAppPermission('max_rules') !== true) &&
-                          $perms->hasAppPermission('max_rules') <= count($filters->getFilterList())) {
+                $max = $perms->hasAppPermission(Ingo_Perms::getPerm('max_rules'));
+                if ($max === 0) {
                     Horde::permissionDeniedError(
                         'ingo',
                         'max_rules',
-                        sprintf(_("You are not allowed to create more than %d rules."), $perms->hasAppPermission('max_rules'))
+                        _("You are not allowed to create or edit custom rules.")
+                    );
+                    break 2;
+                } elseif (($max !== true) &&
+                          ($max <= count($filters->getFilterList()))) {
+                    Horde::permissionDeniedError(
+                        'ingo',
+                        'max_rules',
+                        sprintf(_("You are not allowed to create more than %d rules."), $max)
                     );
                     break 2;
-                } else {
-                    $tmp = $filters->getFilter($this->vars->rulenumber);
-                    if ($filters->copyRule($this->vars->rulenumber)) {
-                        $notification->push(sprintf(_("Rule \"%s\" copied."), $tmp['name']), 'horde.success');
-                    }
                 }
-                break;
 
-            case 'rule_up':
-                $filters->ruleUp($this->vars->rulenumber, $this->vars->get('steps', 1));
-                break;
-
-            case 'rule_down':
-                $filters->ruleDown($this->vars->rulenumber, $this->vars->get('steps', 1));
+                $tmp = $filters->getFilter($this->vars->rulenumber);
+                if ($filters->copyRule($this->vars->rulenumber)) {
+                    $notification->push(sprintf(_("Rule \"%s\" copied."), $tmp['name']), 'horde.success');
+                }
                 break;
 
             case 'rule_disable':
@@ -126,12 +127,10 @@ class Ingo_Basic_Filters extends Ingo_Basic_Base
 
             /* Save changes */
             $ingo_storage->store($filters);
-            if ($prefs->getValue('auto_update')) {
-                try {
-                    Ingo::updateScript();
-                } catch (Ingo_Exception $e) {
-                    $notification->push($e->getMessage(), 'horde.error');
-                }
+            try {
+                Ingo_Script_Util::update();
+            } catch (Ingo_Exception $e) {
+                $notification->push($e->getMessage(), 'horde.error');
             }
             break;
 
@@ -146,11 +145,7 @@ class Ingo_Basic_Filters extends Ingo_Basic_Base
             break;
 
         case 'apply_filters':
-            if (!$edit_allowed) {
-                $notification->push(_("You do not have permission to edit filter rules."), 'horde.error');
-                self::url()->redirect();
-            }
-            $factory->perform($session->get('ingo', 'change'));
+            $factory->perform();
             break;
         }
 
@@ -177,66 +172,86 @@ class Ingo_Basic_Filters extends Ingo_Basic_Base
 
         if (count($filter_list)) {
             $display = array();
-            $i = $rule_count = 0;
             $s_categories = $session->get('ingo', 'script_categories');
 
-            foreach ($filter_list as $val) {
-                if (in_array($val['action'], $s_categories)) {
-                    ++$rule_count;
-                }
-            }
+            $view->can_copy =
+                $edit_allowed &&
+                ((($max_rules = $perms->hasAppPermission(Ingo_Perms::getPerm('max_rules'))) === true) ||
+                ($max_rules > count($filter_list)));
 
             foreach ($filter_list as $rule_number => $filter) {
-                /* Skip non-display categories. */
+                /* Non-display categories. */
                 if (!in_array($filter['action'], $s_categories)) {
+                    $display[$rule_number] = false;
                     continue;
                 }
 
-                $entry = array(
-                    'number' => ++$i
-                );
-                $url = $filters_url->copy()->add('rulenumber', $rule_number);
                 $copyurl = $delurl = $editurl = $name = null;
+                $entry = array();
+                $url = $filters_url->copy()->add('rulenumber', $rule_number);
 
                 switch ($filter['action']) {
                 case Ingo_Storage::ACTION_BLACKLIST:
+                    if (!is_null($mbox_search)) {
+                        continue 2;
+                    }
                     $editurl = Ingo_Basic_Blacklist::url();
-                    $entry['filterimg'] = Horde::img('blacklist.png');
+                    $entry['filterimg'] = 'blacklist.png';
                     $name = _("Blacklist");
                     break;
 
                 case Ingo_Storage::ACTION_WHITELIST:
+                    if (!is_null($mbox_search)) {
+                        continue 2;
+                    }
                     $editurl = Ingo_Basic_Whitelist::url();
-                    $entry['filterimg'] = Horde::img('whitelist.png');
+                    $entry['filterimg'] = 'whitelist.png';
                     $name = _("Whitelist");
                     break;
 
                 case Ingo_Storage::ACTION_VACATION:
+                    if (!is_null($mbox_search)) {
+                        continue 2;
+                    }
                     $editurl = Ingo_Basic_Vacation::url();
-                    $entry['filterimg'] = Horde::img('vacation.png');
+                    $entry['filterimg'] = 'vacation.png';
                     $name = _("Vacation");
                     break;
 
                 case Ingo_Storage::ACTION_FORWARD:
+                    if (!is_null($mbox_search)) {
+                        continue 2;
+                    }
                     $editurl = Ingo_Basic_Forward::url();
-                    $entry['filterimg'] = Horde::img('forward.png');
+                    $entry['filterimg'] = 'forward.png';
                     $name = _("Forward");
                     break;
 
                 case Ingo_Storage::ACTION_SPAM:
+                    if (!is_null($mbox_search)) {
+                        continue 2;
+                    }
                     $editurl = Ingo_Basic_Spam::url();
-                    $entry['filterimg'] = Horde::img('spam.png');
+                    $entry['filterimg'] = 'spam.png';
                     $name = _("Spam Filter");
                     break;
 
                 default:
+                    if (!is_null($mbox_search)) {
+                        if ($mbox_search['exact']) {
+                            if (strcasecmp($filter['action-value'], $mbox_search['query']) !== 0) {
+                                continue 2;
+                            }
+                        } elseif (stripos($filter['action-value'], $mbox_search['query']) === false) {
+                            continue 2;
+                        }
+                    }
+
                     $editurl = $rule_url->copy()->add(array(
-                        'actionID' => 'rule_edit',
                         'edit' => $rule_number
                     ));
                     $delurl = $url->copy()->add('actionID', 'rule_delete');
                     $copyurl = $url->copy()->add('actionID', 'rule_copy');
-                    $entry['filterimg'] = '';
                     $name = $filter['name'];
                     break;
                 }
@@ -245,87 +260,87 @@ class Ingo_Basic_Filters extends Ingo_Basic_Base
                 if (!$edit_allowed) {
                     $entry['descriplink'] = htmlspecialchars($name);
                 } elseif (!empty($filter['conditions'])) {
-                    $entry['descriplink'] = Horde::linkTooltip($editurl, sprintf(_("Edit %s"), $name), null, null, null, Ingo::ruleDescription($filter)) . htmlspecialchars($name) . '</a>';
+                    $entry['descriplink'] = Horde::linkTooltip($editurl, sprintf(_("Edit %s"), $name), null, null, null, $ingo_storage->ruleDescription($filter)) . htmlspecialchars($name) . '</a>';
                 } else {
                     $entry['descriplink'] = Horde::link($editurl, sprintf(_("Edit %s"), $name)) . htmlspecialchars($name) . '</a>';
                 }
 
-                /* Create edit link. */
-                $entry['editlink'] = Horde::link($editurl, sprintf(_("Edit %s"), $name));
-
                 /* Create delete link. */
-                if (!is_null($delurl)) {
+                if ($delete_allowed && !is_null($delurl)) {
                     $entry['dellink'] = Horde::link($delurl, sprintf(_("Delete %s"), $name), null, null, "return window.confirm('" . addslashes(_("Are you sure you want to delete this rule?")) . "');");
-                    $entry['delimg'] = Horde::img('delete.png', sprintf(_("Delete %s"), $name));
-                } else {
-                    $entry['dellink'] = false;
                 }
 
                 /* Create copy link. */
-                if (!is_null($copyurl) &&
-                    (($perms->hasAppPermission('max_rules') === true) ||
-                     $perms->hasAppPermission('max_rules') > count($filter_list))) {
+                if ($view->can_copy && !is_null($copyurl)) {
                     $entry['copylink'] = Horde::link($copyurl, sprintf(_("Copy %s"), $name));
-                    $entry['copyimg'] = Horde::img('copy.png', sprintf(_("Copy %s"), $name));
-                } else {
-                    $entry['copylink'] = false;
                 }
 
-                /* Create up/down arrow links. */
-                $entry['upurl'] = $url->copy()->add('actionID', 'rule_up');
-                $entry['downurl'] = $url->copy()->add('actionID', 'rule_down');
-                $entry['uplink'] = ($i > 1)
-                    ? Horde::link($entry['upurl'], _("Move Rule Up"))
-                    : false;
-                $entry['downlink'] = ($i < $rule_count)
-                    ? Horde::link($entry['downurl'], _("Move Rule Down"))
-                    : false;
-
+                /* Create disable/enable link. */
                 if (empty($filter['disable'])) {
+                    $entry['disabled'] = true;
                     if ($edit_allowed) {
-                        $entry['disablelink'] = Horde::link($url->copy()->add('actionID', 'rule_disable'), sprintf(_("Disable %s"), $name)) .
-                            Horde::img('enable.png', sprintf(_("Disable %s"), $name)) .
-                            '</a>';
-                    } else {
-                        $entry['disablelink'] = Horde::img('enable.png');
+                        $entry['disablelink'] = Horde::link($url->copy()->add('actionID', 'rule_disable'), sprintf(_("Disable %s"), $name));
                     }
-                    $entry['enablelink'] = false;
-                } else {
-                    if ($edit_allowed) {
-                        $entry['enablelink'] = Horde::link($url->copy()->add('actionID', 'rule_enable'), sprintf(_("Enable %s"), $name)) .
-                            Horde::img('disable.png', sprintf(_("Enable %s"), $name)) .
-                            '</a>';
-                    } else {
-                        $entry['enablelink'] = Horde::img('disable.png');
-                    }
-                    $entry['disablelink'] = false;
+                } elseif ($edit_allowed) {
+                    $entry['enablelink'] = Horde::link($url->copy()->add('actionID', 'rule_enable'), sprintf(_("Enable %s"), $name));
                 }
 
-                $display[] = $entry;
+                $display[$rule_number] = $entry;
             }
 
-            // TODO: This can probably be better abstracted into the view file.
             $view->filter = $display;
+            $view->mbox_search = $mbox_search;
         }
 
-        if ($factory->hasFeature('on_demand') && $edit_allowed) {
-            $view->settings = true;
-            $view->flags = $prefs->getValue('filter_seen');
-            $view->show_filter_msg = $prefs->getValue('show_filter_msg');
+        if ($edit_allowed && is_null($mbox_search)) {
+            if ($factory->hasFeature('on_demand')) {
+                $view->settings = true;
+                $view->flags = $prefs->getValue('filter_seen');
+                $view->show_filter_msg = $prefs->getValue('show_filter_msg');
+            }
+
+            $page_output->addScriptFile('hordecore.js', 'horde');
+            $page_output->addScriptPackage('Horde_Core_Script_Package_Sortable');
         }
 
         $page_output->addScriptFile('stripe.js', 'horde');
         $page_output->addScriptFile('filters.js');
 
+        $topbar = $injector->getInstance('Horde_View_Topbar');
+        $topbar->search = true;
+        $topbar->searchAction = self::url();
+        $topbar->searchLabel = _("Mailbox Search");
+        $topbar->searchParameters = array(
+            'actionID' => 'mbox_search',
+            'searchexact' => 0,
+            'page' => 'filters'
+        );
+
         $this->header = _("Filter Rules");
         $this->output = $view->render('filters');
     }
 
     /**
+     * @param array $opts  Additional options:
+     * <pre>
+     *   - mbox_search: (string) Filter results by this mailbox.
+     *   - mbox_search_substr: (boolean) If true, do substring search instead
+     *                         of exact match.
+     * </pre>
      */
     static public function url(array $opts = array())
     {
-        return Horde::url('basic.php')->add('page', 'filters');
+        $url = Horde::url('basic.php')->add('page', 'filters');
+
+        if (isset($opts['mbox_search'])) {
+            $url->add(array(
+                'actionID' => 'mbox_search',
+                'searchexact' => intval(empty($opts['mbox_search_substr'])),
+                'searchfield' => strval($opts['mbox_search'])
+            ));
+        }
+
+        return $url;
     }
 
 }
