@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2003-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2003-2013 Horde LLC
+ * @copyright 2003-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -17,7 +17,7 @@
  * @author    Todd Merritt <tmerritt@email.arizona.edu>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2003-2013 Horde LLC
+ * @copyright 2003-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -27,16 +27,13 @@ class Ingo_Basic_Forward extends Ingo_Basic_Base
      */
     protected function _init()
     {
-        global $injector, $notification, $prefs, $session;
+        global $injector, $notification;
 
         /* Redirect if forward is not available. */
-        if (!in_array(Ingo_Storage::ACTION_FORWARD, $session->get('ingo', 'script_categories'))) {
-            $notification->push(_("Forward is not supported in the current filtering driver."), 'horde.error');
-            self::url()->redirect();
-        }
+        $this->_assertCategory(Ingo_Storage::ACTION_FORWARD, _("Forward"));
 
         if ($this->vars->submitbutton == _("Return to Rules List")) {
-            self::url()->redirect();
+            Ingo_Basic_Filters::url()->redirect();
         }
 
         /* Get the forward object and rule. */
@@ -68,9 +65,7 @@ class Ingo_Basic_Forward extends Ingo_Basic_Base
                     $notification->push(_("Rule Disabled"), 'horde.success');
                     $fwd_rule['disable'] = true;
                 }
-                if ($prefs->getValue('auto_update')) {
-                    Ingo::updateScript();
-                }
+                Ingo_Script_Util::update();
             } catch (Ingo_Exception $e) {
                 $notification->push($e);
             }
@@ -97,7 +92,13 @@ class Ingo_Basic_Forward extends Ingo_Basic_Base
 
         Horde::startBuffer();
         $form->renderActive(
-            new Horde_Form_Renderer(array('encode_title' => false)), $this->vars, self::url(), 'post'
+            new Horde_Form_Renderer(array(
+                'encode_title' => false,
+                'varrenderer_driver' => array('ingo', 'ingo')
+            )),
+            $this->vars,
+            self::url(),
+            'post'
         );
         $this->output = Horde::endBuffer();
     }
