@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -17,7 +17,7 @@
  * @author    Mike Cochrane <mike@graftonhall.co.nz>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -27,11 +27,11 @@ class Ingo_Basic_Rule extends Ingo_Basic_Base
      */
     protected function _init()
     {
-        global $conf, $injector, $notification, $page_output, $prefs, $session;
+        global $conf, $injector, $notification, $page_output;
 
         /* Check rule permissions. */
-        $perms = $injector->getInstance('Horde_Core_Perms');
-        if (!$perms->hasAppPermission('allow_rules')) {
+        $max = $injector->getInstance('Horde_Core_Perms')->hasAppPermission(Ingo_Perms::getPerm('max_rules'));
+        if ($max === 0) {
             Horde::permissionDeniedError(
                 'ingo',
                 'allow_rules',
@@ -40,6 +40,11 @@ class Ingo_Basic_Rule extends Ingo_Basic_Base
             Ingo_Basic_Filters::url()->redirect();
         }
 
+        if (!Ingo::hasSharePermission(Horde_Perms::EDIT)) {
+            $notification->push(_("You do not have permission to edit filter rules."), 'horde.error');
+            Ingo_Basic_Filters::url()->redirect();
+        }
+
         /* Load the Ingo_Script:: driver. */
         $ingo_script = $injector->getInstance('Ingo_Factory_Script')->create(Ingo::RULE_FILTER);
 
@@ -51,86 +56,99 @@ class Ingo_Basic_Rule extends Ingo_Basic_Base
         }
 
         /* This provides the $ingo_fields array. */
-        $ingo_fields = Horde::loadConfiguration('fields.php', 'ingo_fields', 'ingo');
+        $config = new Horde_Registry_LoadConfig('ingo', 'fields.php', 'ingo_fields');
+        $ingo_fields = $config->config['ingo_fields'];
 
         /* Get the current rules. */
         $ingo_storage = $injector->getInstance('Ingo_Factory_Storage')->create();
         $filters = $ingo_storage->retrieve(Ingo_Storage::ACTION_FILTERS);
 
+        if ($this->_assertMaxRules($max, $filters)) {
+            Ingo_Basic_Filters::url()->redirect();
+        }
+
         /* Token checking. */
         $actionID = $this->_checkToken(array(
             'rule_save',
-            'rule_update',
             'rule_delete'
         ));
 
-        /* Run through action handlers. */
-        switch ($actionID) {
-        case 'rule_save':
-        case 'rule_update':
-        case 'rule_delete':
+        /* Update the current rules before performing any action. */
+        if (isset($this->vars->action)) {
             $rule = array(
+                'action' => $this->vars->action,
+                'combine' => $this->vars->combine,
+                'conditions' => array(),
+                'flags' => 0,
                 'id' => $this->vars->id,
                 'name' => $this->vars->name,
-                'combine' => $this->vars->combine,
-                'conditions' => array()
+                'stop' => $this->vars->stop
             );
+        } else {
+            $rule = isset($this->vars->edit)
+                ? $filters->getRule($this->vars->edit)
+                : $filters->getDefaultRule();
+        }
 
-            if ($ingo_script->hasFeature('case_sensitive')) {
-                $casesensitive = $this->vars->case;
+        if (!$rule) {
+            $notification->push(_("Filter not found."), 'horde.error');
+            Ingo_Basic_Filters::url()->redirect();
+        }
+
+        if ($ingo_script->hasFeature('case_sensitive')) {
+            $casesensitive = $this->vars->case;
+        }
+
+        foreach (array_filter(isset($this->vars->field) ? $this->vars->field : array()) as $key => $val) {
+            $condition = array();
+            $f_label = null;
+
+            if ($val == Ingo::USER_HEADER) {
+                $condition['field'] = empty($this->vars->userheader[$key])
+                    ? ''
+                    : $this->vars->userheader[$key];
+                $condition['type'] = Ingo_Storage::TYPE_HEADER;
+            } elseif (!isset($ingo_fields[$val])) {
+                $condition['field'] = $val;
+                $condition['type'] = Ingo_Storage::TYPE_HEADER;
+            } else {
+                $condition['field'] = $val;
+                $f_label = $ingo_fields[$val]['label'];
+                $condition['type'] = $ingo_fields[$val]['type'];
             }
 
-            $valid = true;
-            foreach (array_filter($this->vars->field) as $key => $val) {
-                $condition = array();
-                $f_label = null;
+            $condition['match'] = isset($this->vars->match[$key])
+                ? $this->vars->match[$key]
+                : '';
 
-                if ($val == Ingo::USER_HEADER) {
-                    $condition['field'] = empty($this->vars->userheader[$key])
-                        ? ''
-                        : $this->vars->userheader[$key];
-                    $condition['type'] = Ingo_Storage::TYPE_HEADER;
-                } elseif (!isset($ingo_fields[$val])) {
-                    $condition['field'] = $val;
-                    $condition['type'] = Ingo_Storage::TYPE_HEADER;
-                } else {
-                    $condition['field'] = $val;
-                    $f_label = $ingo_fields[$val]['label'];
-                    $condition['type'] = $ingo_fields[$val]['type'];
-                }
-                $condition['match'] = isset($this->vars->match[$key])
-                    ? $this->vars->match[$key]
-                    : '';
-
-                if (($actionID == 'rule_save') &&
-                    empty($this->vars->value[$key]) &&
-                    !in_array($condition['match'], array('exists', 'not exist'))) {
-                    $notification->push(sprintf(_("You cannot create empty conditions. Please fill in a value for \"%s\"."), is_null($f_label) ? $condition['field'] : $f_label), 'horde.error');
-                    $valid = false;
-                }
-
-                $condition['value'] = isset($this->vars->value[$key])
-                    ? $this->vars->value[$key]
-                    : '';
-
-                if (isset($casesensitive)) {
-                    $condition['case'] = isset($casesensitive[$key])
-                        ? $casesensitive[$key]
-                        : '';
-                }
-                $rule['conditions'][] = $condition;
+            if (($actionID == 'rule_save') &&
+                empty($this->vars->value[$key]) &&
+                !in_array($condition['match'], array('exists', 'not exist'))) {
+                $notification->push(sprintf(_("You cannot create empty conditions. Please fill in a value for \"%s\"."), is_null($f_label) ? $condition['field'] : $f_label), 'horde.error');
+                $actionID = null;
             }
 
-            $rule['action'] = $this->vars->action;
+            $condition['value'] = isset($this->vars->value[$key])
+                ? $this->vars->value[$key]
+                : '';
 
+            if (isset($casesensitive)) {
+                $condition['case'] = isset($casesensitive[$key])
+                    ? $casesensitive[$key]
+                    : '';
+            }
+            $rule['conditions'][] = $condition;
+        }
+
+        if ($this->vars->action) {
             switch ($ingo_storage->getActionInfo($this->vars->action)->type) {
             case 'folder':
                 if ($actionID == 'rule_save') {
                     try {
-                        $rule['action-value'] = Ingo::validateFolder($this->vars, 'actionvalue');
+                        $rule['action-value'] = $this->validateMbox('actionvalue');
                     } catch (Ingo_Exception $e) {
                         $notification->push($e, 'horde.error');
-                        $valid = false;
+                        $actionID = null;
                     }
                 } else {
                     $rule['action-value'] = $this->vars->actionvalue;
@@ -147,94 +165,49 @@ class Ingo_Basic_Rule extends Ingo_Basic_Base
                 $rule['action-value'] = $this->vars->actionvalue;
                 break;
             }
-
-            $rule['stop'] = $this->vars->stop;
-
-            $rule['flags'] = 0;
-            $flags = empty($this->vars->flags)
-                ? array()
-                : $this->vars->flags;
-            foreach ($flags as $val) {
-                $rule['flags'] |= $val;
-            }
-
-            /* Save the rule. */
-            switch ($actionID) {
-            case 'rule_save':
-                if (!$valid) {
-                    break;
-                }
-
-                if (!Ingo::hasSharePermission(Horde_Perms::EDIT)) {
-                    $notification->push(_("You do not have permission to edit filter rules."), 'horde.error');
-                    break;
-                }
-
-                if (empty($rule['conditions'])) {
-                    $notification->push(_("You need to select at least one field to match."), 'horde.error');
-                    break;
-                }
-
-                if (!isset($this->vars->edit)) {
-                    if (($perms->hasAppPermission('max_rules') !== true) &&
-                        ($perms->hasAppPermission('max_rules') <= count($filters->getFilterList()))) {
-                        Horde::permissionDeniedError(
-                            'ingo',
-                            'max_rules',
-                            sprintf(_("You are not allowed to create more than %d rules."), $perms->hasAppPermission('max_rules'))
-                        );
-                        break;
-                    }
-                    $filters->addRule($rule);
-                } else {
-                    $filters->updateRule($rule, $this->vars->edit);
-                }
-
-                $session->set('ingo', 'change', time());
-
-                $ingo_storage->store($filters);
-                $notification->push(_("Changes saved."), 'horde.success');
-
-                if ($prefs->getValue('auto_update')) {
-                    try {
-                        Ingo::updateScript();
-                    } catch (Ingo_Exception $e) {
-                        $notification->push($e, 'horde.error');
-                    }
-                }
-
-                Ingo_Basic_Filters::url()->redirect();
-
-            case 'rule_delete':
-                if (isset($this->vars->conditionnumber)) {
-                    unset($rule['conditions'][intval($this->vars->conditionnumber)]);
-                    $rule['conditions'] = array_values($rule['conditions']);
-                }
-                break;
-            }
-            break;
         }
 
-        if (!isset($rule)) {
-            if (!isset($this->vars->edit)) {
-                if (($perms->hasAppPermission('max_rules') !== true) &&
-                    $perms->hasAppPermission('max_rules') <= count($filters->getFilterList())) {
-                    Horde::permissionDeniedError(
-                        'ingo',
-                        'max_rules',
-                        sprintf(_("You are not allowed to create more than %d rules."), $perms->hasAppPermission('max_rules'))
-                    );
-                    Ingo_Basic_Filters::url()->redirect();
-                }
-                $rule = $filters->getDefaultRule();
-            } else {
-                $rule = $filters->getRule($this->vars->edit);
+        $flags = empty($this->vars->flags)
+            ? array()
+            : $this->vars->flags;
+        foreach ($flags as $val) {
+            $rule['flags'] |= $val;
+        }
+
+        /* Run through action handlers. */
+        switch ($actionID) {
+        case 'rule_save':
+            if (empty($rule['conditions'])) {
+                $notification->push(_("You need to select at least one field to match."), 'horde.error');
+                break;
             }
 
-            if (!$rule) {
-                $notification->push(_("Filter not found."), 'horde.error');
-                Ingo_Basic_Filters::url()->redirect();
+            if (!isset($this->vars->edit)) {
+                if ($this->_assertMaxRules($max, $filters)) {
+                    break;
+                }
+                $filters->addRule($rule);
+            } else {
+                $filters->updateRule($rule, $this->vars->edit);
             }
+
+            $ingo_storage->store($filters);
+            $notification->push(_("Changes saved."), 'horde.success');
+
+            try {
+                Ingo_Script_Util::update();
+            } catch (Ingo_Exception $e) {
+                $notification->push($e, 'horde.error');
+            }
+
+            Ingo_Basic_Filters::url()->redirect();
+
+        case 'rule_delete':
+            if (isset($this->vars->conditionnumber)) {
+                unset($rule['conditions'][intval($this->vars->conditionnumber)]);
+                $rule['conditions'] = array_values($rule['conditions']);
+            }
+            break;
         }
 
         /* Add new, blank condition. */
@@ -245,6 +218,7 @@ class Ingo_Basic_Rule extends Ingo_Basic_Base
             'templatePath' => INGO_TEMPLATES . '/basic/rule'
         ));
         $view->addHelper('Horde_Core_View_Helper_Help');
+        $view->addHelper('Horde_Core_View_Helper_Image');
         $view->addHelper('Horde_Core_View_Helper_Label');
         $view->addHelper('FormTag');
         $view->addHelper('Tag');
@@ -346,7 +320,7 @@ class Ingo_Basic_Rule extends Ingo_Basic_Base
             switch ($current_action->type) {
             case 'folder':
                 $view->actionvaluelabel = _("Select target folder");
-                $view->actionvalue = Ingo::flistSelect($rule['action-value']);
+                $view->actionvalue = Ingo_Flist::select($rule['action-value']);
                 break;
 
             case 'text':
@@ -369,6 +343,24 @@ class Ingo_Basic_Rule extends Ingo_Basic_Base
         $this->output = $view->render('rule');
     }
 
+    /**
+     * @param mixed $max
+     * @param Ingo_Storage_Filters $filters
+     */
+    protected function _assertMaxRules($max, $filters)
+    {
+        if (($max !== true) && ($max <= count($filters->getFilterList()))) {
+            Horde::permissionDeniedError(
+                'ingo',
+                'max_rules',
+                sprintf(_("You are not allowed to create more than %d rules."), $max)
+            );
+            return true;
+        }
+
+        return false;
+    }
+
     /**
      */
     static public function url(array $opts = array())
