@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -18,7 +18,7 @@
  * @author    Jan Schneider <jan@horde.org>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -51,23 +51,16 @@ class Ingo_Basic_Script extends Ingo_Basic_Base
         /* Activate/deactivate script if requested. */
         switch ($actionID) {
         case 'action_activate':
+        case 'action_deactivate':
             if (!empty($scripts)) {
                 try {
-                    Ingo::activateScripts($scripts, false);
+                    Ingo_Script_Util::activate($scripts, $actionID == 'action_deactivate');
                 } catch (Ingo_Exception $e) {
                     $notification->push($e);
                 }
             }
             break;
 
-        case 'action_deactivate':
-            try {
-                Ingo::activateScripts('', true);
-            } catch (Ingo_Exception $e) {
-                $notification->push($e);
-            }
-            break;
-
         case 'show_active':
             $scripts = array();
             foreach ($session->get('ingo', 'backend/transport', Horde_Session::TYPE_ARRAY) as $transport) {
