@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -18,7 +18,7 @@
  * @author    Jan Schneider <jan@horde.org>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -28,12 +28,9 @@ class Ingo_Basic_Spam extends Ingo_Basic_Base
      */
     protected function _init()
     {
-        global $injector, $notification, $session, $prefs;
+        global $injector, $notification;
 
-        if (!in_array(Ingo_Storage::ACTION_SPAM, $session->get('ingo', 'script_categories'))) {
-            $notification->push(_("Simple spam filtering is not supported in the current filtering driver."), 'horde.error');
-            Ingo_Basic_Filters::url()->redirect();
-        }
+        $this->_assertCategory(Ingo_Storage::ACTION_SPAM, _("Spam filtering"));
 
         /* Get the spam object and rule. */
         $ingo_storage = $injector->getInstance('Ingo_Factory_Storage')->create();
@@ -59,7 +56,7 @@ class Ingo_Basic_Spam extends Ingo_Basic_Base
             $success = false;
 
             try {
-                $spam->setSpamFolder(Ingo::validateFolder($this->vars, 'folder'));
+                $spam->setSpamFolder($this->validateMbox('folder'));
                 $success = true;
             } catch (Horde_Exception $e) {
                 $notification->push($e);
@@ -81,15 +78,10 @@ class Ingo_Basic_Spam extends Ingo_Basic_Base
                     $notification->push(_("Rule Disabled"), 'horde.success');
                     $spam_rule['disable'] = true;
                 }
-                if ($prefs->getValue('auto_update')) {
-                    Ingo::updateScript();
-                }
+                Ingo_Script_Util::update();
             } catch (Ingo_Exception $e) {
                 $notification->push($e);
             }
-
-            /* Update the timestamp for the rules. */
-            $session->set('ingo', 'change', time());
         }
 
         /* Add buttons depending on the above actions. */
@@ -129,10 +121,10 @@ class Ingo_Basic_Spam extends Ingo_Basic_Base
 
 
 /**
- * Dummy class to hold the select box created by {@link Ingo::flistSelect()}.
+ * Dummy class to hold the select box created by {@link Ingo_Flist::select()}.
  *
  * @see Horde_Core_Ui_VarRenderer_Ingo
- * @see Ingo::flistSelect()
+ * @see Ingo_Flist::select()
  */
 class Horde_Form_Type_ingo_folders extends Horde_Form_Type {
 
