@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -17,7 +17,7 @@
  * @author    Mike Cochrane <mike@graftonhall.co.nz>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -27,13 +27,9 @@ class Ingo_Basic_Vacation extends Ingo_Basic_Base
      */
     protected function _init()
     {
-        global $injector, $notification, $prefs, $session;
+        global $injector, $notification;
 
-        /* Redirect if vacation is not available. */
-        if (!in_array(Ingo_Storage::ACTION_VACATION, $session->get('ingo', 'script_categories'))) {
-            $notification->push(_("Vacation is not supported in the current filtering driver."), 'horde.error');
-            Ingo_Basic_Filters::url()->redirect();
-        }
+        $this->_assertCategory(Ingo_Storage::ACTION_VACATION, _("Vacation"));
 
         /* Get vacation object and rules. */
         $ingo_storage = $injector->getInstance('Ingo_Factory_Storage')->create();
@@ -82,15 +78,11 @@ class Ingo_Basic_Vacation extends Ingo_Basic_Base
                     $notification->push(_("Rule Disabled"), 'horde.success');
                     $vac_rule['disable'] = true;
                 }
-                if ($prefs->getValue('auto_update')) {
-                    Ingo::updateScript();
-                }
+
+                Ingo_Script_Util::update();
             } catch (Ingo_Exception $e) {
                 $notification->push($e);
             }
-
-            /* Update the timestamp for the rules. */
-            $session->set('ingo', 'change', time());
         }
 
         /* Add buttons depending on the above actions. */
@@ -138,7 +130,10 @@ class Ingo_Basic_Vacation extends Ingo_Basic_Base
 
         Horde::startBuffer();
         $form->renderActive(
-            new Horde_Form_Renderer(array('encode_title' => false)),
+            new Horde_Form_Renderer(array(
+                'encode_title' => false,
+                'varrenderer_driver' => array('ingo', 'ingo')
+            )),
             $this->vars,
             self::url(),
             'post'
