@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2002-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2002-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
  *
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -18,7 +18,7 @@
  * @author    Brent J. Nordquist <bjn@horde.org>
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2002-2013 Horde LLC
+ * @copyright 2002-2014 Horde LLC
  * @license   http://www.horde.org/licenses/apache ASL
  * @package   Ingo
  */
@@ -28,32 +28,20 @@ class Ingo_Basic_Whitelist extends Ingo_Basic_Base
      */
     protected function _init()
     {
-        global $injector, $notification, $page_output, $prefs, $session;
+        global $injector, $notification, $page_output;
 
-        /* Redirect if whitelist not available. */
-        if (!in_array(Ingo_Storage::ACTION_WHITELIST, $session->get('ingo', 'script_categories'))) {
-            $notification->push(_("Whitelist is not supported in the current filtering driver."), 'horde.error');
-            Ingo_Basic_Filters::url()->redirect();
-        }
+        $this->_assertCategory(Ingo_Storage::ACTION_WHITELIST, _("Whitelist"));
 
         $ingo_storage = $injector->getInstance('Ingo_Factory_Storage')->create();
         $whitelist = $ingo_storage->retrieve(Ingo_Storage::ACTION_WHITELIST);
 
-        /* Token checking. */
-        $actionID = $this->_checkToken(array('rule_update'));
-
-        /* Perform requested actions. */
-        switch ($actionID) {
+        /* Token checking & perform requested actions. */
+        switch ($this->_checkToken(array('rule_update'))) {
         case 'rule_update':
             try {
                 Ingo::updateListFilter($this->vars->whitelist, Ingo_Storage::ACTION_WHITELIST);
                 $notification->push(_("Changes saved."), 'horde.success');
-                if ($prefs->getValue('auto_update')) {
-                    Ingo::updateScript();
-                }
-
-                /* Update the timestamp for the rules. */
-                $session->set('ingo', 'change', time());
+                Ingo_Script_Util::update();
             } catch (Ingo_Exception $e) {
                 $notification->push($e);
             }
