@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2003-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -126,7 +126,6 @@ class Ingo_Script_Procmail_Recipe implements Ingo_Script_Item
             $this->_action[] = '  :0 Wh';
             $this->_action[] = '  * !^FROM_DAEMON';
             $this->_action[] = '  * !^X-Loop: $SENDER';
-            $this->_action[] = '  :0 eh';
             $this->_action[] = '  | (formail -rA"X-Loop: $SENDER" \\';
             $reason = $params['action-value'];
             if (Horde_Mime::is8bit($reason)) {
@@ -192,9 +191,11 @@ class Ingo_Script_Procmail_Recipe implements Ingo_Script_Item
                     $this->_action[] = '      | (formail -rI"Precedence: junk" \\';
                     $this->_action[] = '       -a"From: <' . $address . '>" \\';
                     $this->_action[] = '       -A"X-Loop: ' . $address . '" \\';
-                    $reason = Ingo::getReason($params['action-value']['reason'],
-                                              $params['action-value']['start'],
-                                              $params['action-value']['end']);
+                    $reason = Ingo_Script_Util::vacationReason(
+                        $params['action-value']['reason'],
+                        $params['action-value']['start'],
+                        $params['action-value']['end']
+                    );
                     if (Horde_Mime::is8bit($reason)) {
                         $this->_action[] = '       -i"Subject: ' . Horde_Mime::encode($params['action-value']['subject'] . ' (Re: $SUBJECT)') . '" \\';
                         $this->_action[] = '       -i"Content-Transfer-Encoding: quoted-printable" \\';
