@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2012-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -38,7 +38,22 @@ class Ingo_Storage_Forward extends Ingo_Storage_Rule
      */
     public function setForwardAddresses($data)
     {
-        $this->_addr = $this->_addressList($data);
+        $addr = $this->_addressList($data);
+        $max = $GLOBALS['injector']->getInstance('Horde_Core_Perms')
+            ->hasAppPermission(Ingo_Perms::getPerm('max_forward'));
+
+        if (($max !== true) && !empty($max)) {
+            $addr_count = count($addr);
+            if ($addr_count > $max) {
+                throw new Ingo_Exception(sprintf(
+                    _("Maximum number of forward addresses exceeded (Total addresses: %s, Maximum addresses: %s)."),
+                    $addr_count,
+                    $max
+                ));
+            }
+        }
+
+        $this->_addr = $addr;
     }
 
     /**
